@@ -1,5 +1,3 @@
-use std::cell::RefCell;
-use std::collections::HashMap;
 use std::future::Future;
 use std::ops::{Deref, DerefMut};
 
@@ -129,16 +127,6 @@ where
         self.parser.add_callback(uid, callback);
     }
 
-    /// Get the callback hash map reference.
-    pub fn get_callback(&self) -> &HashMap<Uid, RefCell<OptCallback>> {
-        self.parser.get_service().get_callback()
-    }
-
-    /// Get the callback hash map mutable reference.
-    pub fn get_callback_mut(&mut self) -> &mut HashMap<Uid, RefCell<OptCallback>> {
-        self.parser.get_service_mut().get_callback_mut()
-    }
-
     /// Running function after parsing.
     ///
     /// # Example
