@@ -10,7 +10,7 @@ use crate::uid::Uid;
 ///
 /// Since rust has a lot of restrict on reference.
 /// So we can't store block code into option itself of [`Set`](crate::set::Set).
-/// Instead we put the callback code into [`Parser`](crate::parser::Parser).
+/// Instead we put the callback code into [`Service`](crate::parser::Service).
 #[derive(Debug, Clone, PartialEq, Eq, Hash)]
 pub enum CallbackType {
     Opt,
@@ -105,15 +105,18 @@ impl<'a> From<&'a Callback> for CallbackType {
     }
 }
 
-pub trait OptCallback: Debug {
+/// Callback trait using for [`Callback::Opt`], associated callback type is [`CallbackType::Opt`].
+pub trait OptFn: Debug {
     fn call(&mut self, uid: Uid, set: &dyn Set, value: OptValue) -> Result<Option<OptValue>>;
 }
 
-pub trait OptMutCallback: Debug {
+/// Callback trait using for [`Callback::OptMut`], associated callback type is [`CallbackType::OptMut`].
+pub trait OptFnMut: Debug {
     fn call(&mut self, uid: Uid, set: &mut dyn Set, value: OptValue) -> Result<Option<OptValue>>;
 }
 
-pub trait PosCallback: Debug {
+/// Callback trait using for [`Callback::Pos`], associated callback type is [`CallbackType::Pos`].
+pub trait PosFn: Debug {
     fn call(
         &mut self,
         uid: Uid,
@@ -124,7 +127,8 @@ pub trait PosCallback: Debug {
     ) -> Result<Option<OptValue>>;
 }
 
-pub trait PosMutCallback: Debug {
+/// Callback trait using for [`Callback::PosMut`], associated callback type is [`CallbackType::PosMut`].
+pub trait PosFnMut: Debug {
     fn call(
         &mut self,
         uid: Uid,
@@ -135,7 +139,8 @@ pub trait PosMutCallback: Debug {
     ) -> Result<Option<OptValue>>;
 }
 
-pub trait MainCallback: Debug {
+/// Callback trait using for [`Callback::Main`], associated callback type is [`CallbackType::Main`].
+pub trait MainFn: Debug {
     fn call(
         &mut self,
         uid: Uid,
@@ -145,7 +150,8 @@ pub trait MainCallback: Debug {
     ) -> Result<Option<OptValue>>;
 }
 
-pub trait MainMutCallback: Debug {
+/// Callback trait using for [`Callback::MainMut`], associated callback type is [`CallbackType::MainMut`].
+pub trait MainFnMut: Debug {
     fn call(
         &mut self,
         uid: Uid,
@@ -155,19 +161,20 @@ pub trait MainMutCallback: Debug {
     ) -> Result<Option<OptValue>>;
 }
 
+/// The callback type hold block code.
 #[derive(Debug)]
 pub enum Callback {
-    Opt(Box<dyn OptCallback>),
+    Opt(Box<dyn OptFn>),
 
-    OptMut(Box<dyn OptMutCallback>),
+    OptMut(Box<dyn OptFnMut>),
 
-    Pos(Box<dyn PosCallback>),
+    Pos(Box<dyn PosFn>),
 
-    PosMut(Box<dyn PosMutCallback>),
+    PosMut(Box<dyn PosFnMut>),
 
-    Main(Box<dyn MainCallback>),
+    Main(Box<dyn MainFn>),
 
-    MainMut(Box<dyn MainMutCallback>),
+    MainMut(Box<dyn MainFnMut>),
 
     Null,
 }
@@ -204,47 +211,48 @@ impl Callback {
     }
 }
 
-impl From<Box<dyn OptCallback>> for Callback {
-    fn from(cb: Box<dyn OptCallback>) -> Self {
+impl From<Box<dyn OptFn>> for Callback {
+    fn from(cb: Box<dyn OptFn>) -> Self {
         Callback::Opt(cb)
     }
 }
 
-impl From<Box<dyn OptMutCallback>> for Callback {
-    fn from(cb: Box<dyn OptMutCallback>) -> Self {
+impl From<Box<dyn OptFnMut>> for Callback {
+    fn from(cb: Box<dyn OptFnMut>) -> Self {
         Callback::OptMut(cb)
     }
 }
 
-impl From<Box<dyn PosCallback>> for Callback {
-    fn from(cb: Box<dyn PosCallback>) -> Self {
+impl From<Box<dyn PosFn>> for Callback {
+    fn from(cb: Box<dyn PosFn>) -> Self {
         Callback::Pos(cb)
     }
 }
 
-impl From<Box<dyn PosMutCallback>> for Callback {
-    fn from(cb: Box<dyn PosMutCallback>) -> Self {
+impl From<Box<dyn PosFnMut>> for Callback {
+    fn from(cb: Box<dyn PosFnMut>) -> Self {
         Callback::PosMut(cb)
     }
 }
 
-impl From<Box<dyn MainCallback>> for Callback {
-    fn from(cb: Box<dyn MainCallback>) -> Self {
+impl From<Box<dyn MainFn>> for Callback {
+    fn from(cb: Box<dyn MainFn>) -> Self {
         Callback::Main(cb)
     }
 }
 
-impl From<Box<dyn MainMutCallback>> for Callback {
-    fn from(cb: Box<dyn MainMutCallback>) -> Self {
+impl From<Box<dyn MainFnMut>> for Callback {
+    fn from(cb: Box<dyn MainFnMut>) -> Self {
         Callback::MainMut(cb)
     }
 }
 
-pub struct SimpleOptCallback<'a, T>(T, PhantomData<&'a T>)
+/// Simple struct implemented [`OptFn`].
+pub struct SimpleOptFn<'a, T>(T, PhantomData<&'a T>)
 where
     T: 'a + Fn(Uid, &dyn Set, OptValue) -> Result<Option<OptValue>>;
 
-impl<'a, T> SimpleOptCallback<'a, T>
+impl<'a, T> SimpleOptFn<'a, T>
 where
     T: 'a + Fn(Uid, &dyn Set, OptValue) -> Result<Option<OptValue>>,
 {
@@ -253,18 +261,18 @@ where
     }
 }
 
-impl<'a, T> Debug for SimpleOptCallback<'a, T>
+impl<'a, T> Debug for SimpleOptFn<'a, T>
 where
     T: 'a + Fn(Uid, &dyn Set, OptValue) -> Result<Option<OptValue>>,
 {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        f.debug_struct("SimpleOptCallback")
+        f.debug_struct("SimpleOptFn")
             .field("Fn", &String::from("..."))
             .finish()
     }
 }
 
-impl<'a, T> OptCallback for SimpleOptCallback<'a, T>
+impl<'a, T> OptFn for SimpleOptFn<'a, T>
 where
     T: 'a + Fn(Uid, &dyn Set, OptValue) -> Result<Option<OptValue>>,
 {
@@ -273,11 +281,12 @@ where
     }
 }
 
-pub struct SimpleOptMutCallback<'a, T>(T, PhantomData<&'a T>)
+/// Simple struct implemented [`OptFnMut`].
+pub struct SimpleOptFnMut<'a, T>(T, PhantomData<&'a T>)
 where
     T: 'a + FnMut(Uid, &mut dyn Set, OptValue) -> Result<Option<OptValue>>;
 
-impl<'a, T> SimpleOptMutCallback<'a, T>
+impl<'a, T> SimpleOptFnMut<'a, T>
 where
     T: 'a + FnMut(Uid, &mut dyn Set, OptValue) -> Result<Option<OptValue>>,
 {
@@ -286,18 +295,18 @@ where
     }
 }
 
-impl<'a, T> Debug for SimpleOptMutCallback<'a, T>
+impl<'a, T> Debug for SimpleOptFnMut<'a, T>
 where
     T: 'a + FnMut(Uid, &mut dyn Set, OptValue) -> Result<Option<OptValue>>,
 {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        f.debug_struct("SimpleOptMutCallback")
+        f.debug_struct("SimpleOptFnMut")
             .field("FnMut", &String::from("..."))
             .finish()
     }
 }
 
-impl<'a, T> OptMutCallback for SimpleOptMutCallback<'a, T>
+impl<'a, T> OptFnMut for SimpleOptFnMut<'a, T>
 where
     T: 'a + FnMut(Uid, &mut dyn Set, OptValue) -> Result<Option<OptValue>>,
 {
@@ -306,11 +315,12 @@ where
     }
 }
 
-pub struct SimplePosCallback<'a, T>(T, PhantomData<&'a T>)
+/// Simple struct implemented [`PosFn`].
+pub struct SimplePosFn<'a, T>(T, PhantomData<&'a T>)
 where
     T: 'a + Fn(Uid, &dyn Set, &str, u64, OptValue) -> Result<Option<OptValue>>;
 
-impl<'a, T> SimplePosCallback<'a, T>
+impl<'a, T> SimplePosFn<'a, T>
 where
     T: 'a + Fn(Uid, &dyn Set, &str, u64, OptValue) -> Result<Option<OptValue>>,
 {
@@ -319,18 +329,18 @@ where
     }
 }
 
-impl<'a, T> Debug for SimplePosCallback<'a, T>
+impl<'a, T> Debug for SimplePosFn<'a, T>
 where
     T: 'a + Fn(Uid, &dyn Set, &str, u64, OptValue) -> Result<Option<OptValue>>,
 {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        f.debug_struct("SimplePosCallback")
+        f.debug_struct("SimplePosFn")
             .field("Fn", &String::from("..."))
             .finish()
     }
 }
 
-impl<'a, T> PosCallback for SimplePosCallback<'a, T>
+impl<'a, T> PosFn for SimplePosFn<'a, T>
 where
     T: 'a + Fn(Uid, &dyn Set, &str, u64, OptValue) -> Result<Option<OptValue>>,
 {
@@ -346,11 +356,12 @@ where
     }
 }
 
-pub struct SimplePosMutCallback<'a, T>(T, PhantomData<&'a T>)
+/// Simple struct implemented [`PosFnMut`].
+pub struct SimplePosFnMut<'a, T>(T, PhantomData<&'a T>)
 where
     T: 'a + FnMut(Uid, &mut dyn Set, &str, u64, OptValue) -> Result<Option<OptValue>>;
 
-impl<'a, T> SimplePosMutCallback<'a, T>
+impl<'a, T> SimplePosFnMut<'a, T>
 where
     T: 'a + FnMut(Uid, &mut dyn Set, &str, u64, OptValue) -> Result<Option<OptValue>>,
 {
@@ -359,18 +370,18 @@ where
     }
 }
 
-impl<'a, T> Debug for SimplePosMutCallback<'a, T>
+impl<'a, T> Debug for SimplePosFnMut<'a, T>
 where
     T: 'a + FnMut(Uid, &mut dyn Set, &str, u64, OptValue) -> Result<Option<OptValue>>,
 {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        f.debug_struct("SimplePosMutCallback")
+        f.debug_struct("SimplePosFnMut")
             .field("FnMut", &String::from("..."))
             .finish()
     }
 }
 
-impl<'a, T> PosMutCallback for SimplePosMutCallback<'a, T>
+impl<'a, T> PosFnMut for SimplePosFnMut<'a, T>
 where
     T: 'a + FnMut(Uid, &mut dyn Set, &str, u64, OptValue) -> Result<Option<OptValue>>,
 {
@@ -386,11 +397,12 @@ where
     }
 }
 
-pub struct SimpleMainCallback<'a, T>(T, PhantomData<&'a T>)
+/// Simple struct implemented [`MainFn`].
+pub struct SimpleMainFn<'a, T>(T, PhantomData<&'a T>)
 where
     T: 'a + Fn(Uid, &dyn Set, &[&str], OptValue) -> Result<Option<OptValue>>;
 
-impl<'a, T> SimpleMainCallback<'a, T>
+impl<'a, T> SimpleMainFn<'a, T>
 where
     T: 'a + Fn(Uid, &dyn Set, &[&str], OptValue) -> Result<Option<OptValue>>,
 {
@@ -399,18 +411,18 @@ where
     }
 }
 
-impl<'a, T> Debug for SimpleMainCallback<'a, T>
+impl<'a, T> Debug for SimpleMainFn<'a, T>
 where
     T: 'a + Fn(Uid, &dyn Set, &[&str], OptValue) -> Result<Option<OptValue>>,
 {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        f.debug_struct("SimpleMainCallback")
+        f.debug_struct("SimpleMainFn")
             .field("Fn", &String::from("..."))
             .finish()
     }
 }
 
-impl<'a, T> MainCallback for SimpleMainCallback<'a, T>
+impl<'a, T> MainFn for SimpleMainFn<'a, T>
 where
     T: 'a + Fn(Uid, &dyn Set, &[&str], OptValue) -> Result<Option<OptValue>>,
 {
@@ -425,11 +437,12 @@ where
     }
 }
 
-pub struct SimpleMainMutCallback<'a, T>(T, PhantomData<&'a T>)
+/// Simple struct implemented [`MainFnMut`].
+pub struct SimpleMainFnMut<'a, T>(T, PhantomData<&'a T>)
 where
     T: 'a + FnMut(Uid, &mut dyn Set, &[&str], OptValue) -> Result<Option<OptValue>>;
 
-impl<'a, T> SimpleMainMutCallback<'a, T>
+impl<'a, T> SimpleMainFnMut<'a, T>
 where
     T: 'a + FnMut(Uid, &mut dyn Set, &[&str], OptValue) -> Result<Option<OptValue>>,
 {
@@ -438,18 +451,18 @@ where
     }
 }
 
-impl<'a, T> Debug for SimpleMainMutCallback<'a, T>
+impl<'a, T> Debug for SimpleMainFnMut<'a, T>
 where
     T: 'a + FnMut(Uid, &mut dyn Set, &[&str], OptValue) -> Result<Option<OptValue>>,
 {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        f.debug_struct("SimpleMainMutCallback")
+        f.debug_struct("SimpleMainFnMut")
             .field("FnMut", &String::from("..."))
             .finish()
     }
 }
 
-impl<'a, T> MainMutCallback for SimpleMainMutCallback<'a, T>
+impl<'a, T> MainFnMut for SimpleMainFnMut<'a, T>
 where
     T: 'a + FnMut(Uid, &mut dyn Set, &[&str], OptValue) -> Result<Option<OptValue>>,
 {
